@@ -1,5 +1,8 @@
 package App::Netdisco::AnyEvent::Nbtstat;
 
+use strict;
+use warnings;
+
 use Socket qw(AF_INET SOCK_DGRAM inet_aton sockaddr_in);
 use List::Util ();
 use Carp       ();
